==> NETXave-0.0.5.crate: NETXave-0.0.5/src/protocols/dns/client/types/message/sections/Header/RCODES_m/mod.rs <==
/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

mod constants;
mod conversion;
mod rcodes_m;
mod rcode_info;
mod rcode_raw_info;
mod rcode_edns_info;

mod warnings;

pub(self) use constants::{REVERSED, UNASSIGNED, REVERSED_PRIVATE_USE};
pub(self) use warnings::{NOT_AUTH_W, BAD_VERS_BAD_SIG_W};

pub use rcodes_m::{RCODES};
pub use rcode_info::{RCODEInfo};
pub use rcode_raw_info::{RCODERawInfo};
pub use rcode_edns_info::{RCODEEDNSInfo};
pub use conversion::{RCODEConversion};

==> NETXave-0.0.6.crate: NETXave-0.0.6/src/protocols/dns/client/types/message/sections/Header/RCODES_m/mod.rs <==
/*
 * Copyright 2023 Stanislav Mikhailov (xavetar)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

mod constants;
mod conversion;
mod rcodes_m;
mod rcode_info;
mod rcode_raw_info;
mod rcode_edns_info;

mod warnings;

pub(self) use constants::{RESERVED, UNASSIGNED, RESERVED_PRIVATE_USE};
pub(self) use warnings::{NOT_AUTH_W, BAD_VERS_BAD_SIG_W};

pub use rcodes_m::{RCODES};
pub use rcode_info::{RCODEInfo};
pub use rcode_raw_info::{RCODERawInfo};
pub use rcode_edns_info::{RCODEEDNSInfo};
pub use conversion::{RCODEConversion};
